/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

typedef enum
{
	TOOLBAR_TYPE_NONE,
	TOOLBAR_TYPE_TOOLBAR,
	TOOLBAR_TYPE_MENUBAR
} ToolbarType;

void toolbar_create (GaleonWindow *window, gboolean show);
void toolbar_recreate (GaleonWindow *window);
void toolbar_set_dock_style (GtkWidget *dock, ToolbarType type,
		             GtkToolbarStyle toolbar_style);

extern const ToolbarItem toolbar_items[TOOLBAR_ITEM_COUNT];
